local _, L = ...; -- Let's use the private table passed to every .lua 

local function defaultFunc(L, key)
 -- If this function was called, we have no localization for this key.
 -- We could complain loudly to allow localizers to see the error of their ways, 
 -- but, for now, just return the key as its own localization. This allows you to—avoid writing the default localization out explicitly.
 return key;
end
setmetatable(L, {__index=defaultFunc});

local LOCALE = GetLocale()

if LOCALE == "enUS" then
	-- The EU English game client also
	-- uses the US English locale code.
	L["Vigor"] = "Vigor"
	L["Speedometer"] = "Speedometer"
	L["ToggleModelsName"] = "Show Vigor Models"
	L["ToggleModelsTT"] = "Display the swirling model effect on the vigor bubbles."
	L["SpeedPosPointName"] = "Speedometer Position"
	L["SpeedPosPointTT"] = "Adjusts where the speedometer is anchored to relative to the vigor bar."
	L["Top"] = "Top"
	L["Bottom"] = "Bottom"
	L["Left"] = "Left"
	L["Right"] = "Right"
	L["SpeedPosXName"] = "Speedometer Horizontal Position"
	L["SpeedPosXTT"] = "Adjust the horizontal position of the speedometer."
	L["SpeedPosYName"] = "Speedometer Vertical Position"
	L["SpeedPosYTT"] = "Adjust the vertical position of the speedometer."
	L["SpeedScaleName"] = "Speedometer Scale"
	L["SpeedScaleTT"] = "Adjust the scale of the speedometer."
	L["Large"] = "Large"
	L["Small"] = "Small"
	L["Units"] = "Speedometer Text"
	L["UnitsTT"] = "Change the units displayed on the speedometer.\n(Mechanically 1 metre = 1 yard)"
	L["UnitsColor"] = "Speedometer Text Color"
	L["UnitYards"] = "yds/s"
	L["Yards"] = "Yards"
	L["UnitMiles"] = "mph"
	L["Miles"] = "Miles"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "Metres"
	L["UnitKilometers"] = "km/h"
	L["Kilometers"] = "Kilometres"
	L["UnitPercent"] = "%"
	L["Percent"] = "Percentage"
	L["SpeedTextScale"] = "Speedometer Text Size"
	L["SpeedTextScaleTT"] = "Adjust the size of the text on the speedometer."
	L["Version"] = "Version %s"
	L["ResetAllSettings"] = "Reset all Dragon Rider settings"
	L["ResetAllSettingsTT"] = "Resets all settings specifically for this addon. This will include the custom color values."
	L["ResetAllSettingsConfirm"] = "Are you sure you want to reset the settings for Dragon Rider?"
	L["Low"] = "Low"
	L["High"] = "High"
	L["ProgressBar"] = "Speedometer"
	L["ProgressBarColor"] = "Speedometer Color"
	L["ColorPickerLowProgTT"] = "Choose a custom color for the low speed values of the speedometer. This occurs when the player is not gaining any vigor."
	L["ColorPickerMidProgTT"] = "Choose a custom color for the vigor speed values of the speedometer. This occurs when the player is gaining vigor within standard a speed range."
	L["ColorPickerHighProgTT"] = "Choose a custom color for the high speed values of the speedometer. This occurs when the player is gaining vigor, but is above the standard speed range."
	L["ColorPickerLowTextTT"] = "Choose a custom color for the low speed values of the speed value. This occurs when the player is not gaining any vigor."
	L["ColorPickerMidTextTT"] = "Choose a custom color for the vigor speed values of the speed value. This occurs when the player is gaining vigor within standard a speed range."
	L["ColorPickerHighTextTT"] = "Choose a custom color for the high speed values of the speed value. This occurs when the player is gaining vigor, but is above the standard speed range."
	L["DragonridingTalents"] = "Dragonriding Talents"
	L["OpenDragonridingTalents"] = "Open Dragonriding Talents"
	L["OpenDragonridingTalentsTT"] = "Open Dragonriding Talents Window."
	L["SideArtName"] = "Side Art"
	L["SideArtTT"] = "Toggle the art on the sides of the main Vigor bar."
	L["BugfixesName"] = "Bugfixes"
	L["BugfixesTT"] = "Experimental bug fix attempts for when default Blizzard frames aren't working as intended."
	L["BugfixHideVigor"] = "Force Hide Vigor"
	L["BugfixHideVigorTT"] = "Force hide the vigor bar when dismounted, and re-show when mounted on a dynamic flying mount."
	L["FadeSpeedometer"] = "Fade Speedometer"
	L["FadeSpeedometerTT"] = "Toggle fading the Speedometer when not gliding."
	L["ShowVigorTooltip"] = "Show Vigor Tooltip"
	L["ShowVigorTooltipTT"] = "Toggle the tooltip that displays upon the Vigor bar."
	L["FadeVigor"] = "Fade Vigor"
	L["FadeVigorTT"] = "Toggle fading the Vigor bar when not gliding and while at full Vigor."
	L["LightningRush"] = "Static Charge Orbs"
	L["LightningRushTT"] = "Toggle custom frames made for Static Charge auras which are used by the Algarian Stormrider's Lightning Rush ability."
	L["DynamicFOV"] = "Dynamic FOV"
	L["DynamicFOVTT"] = "Enables adjustment of camera field of view based on gliding speed."
	L["Normal"] = "Normal"
	L["Advanced"] = "Advanced"
	L["Reverse"] = "Reverse"
	L["Challenge"] = "Challenge"
	L["ReverseChallenge"] = "Reverse Challenge"
	L["Storm"] = "Storm"
	L["COMMAND_help"] = "help"
	L["COMMAND_journal"] = "journal"
	L["COMMAND_listcommands"] = "A list of commands:"
	L["COMMAND_dragonrider"] = "dragonrider"
	L["DragonRider"] = "Dragon Rider"
	L["RightClick_TT_Line"] = "Right-Click: Open Settings"
	L["LeftClick_TT_Line"] = "Left-Click: Open Journal"
	L["SlashCommands_TT_Line"] = "'/dragonrider' for additional commands"
	L["Score"] = "Score"
	L["Guide"] = "Guide"
	L["Settings"] = "Settings"
	L["ComingSoon"] = "Coming Soon"
	L["UseAccountScores"] = "Use Account Scores"
	L["UseAccountScoresTT"] = "This will display your top account race scores instead of your character's scores. Account scores are indicated with an asterisk (*)."
	L["PersonalBest"] = "Personal Best: "
	L["AccountBest"] = "Account Best: "
	L["BestCharacter"] = "Best Character: "
	L["GoldTime"] = "Gold Time: "
	L["SilverTime"] = "Silver Time: "
	--L["SetMapPin_TT"] = "Click to set Map Pin"

return end

if LOCALE == "esES" or LOCALE == "esMX" then
	-- Spanish translations go here
	L["Vigor"] = "Vigor"
	L["Speedometer"] = "Velocímetro"
	L["ToggleModelsName"] = "Mostrar modelos de vigor"
	L["ToggleModelsTT"] = "Muestre el efecto del modelo de remolino en las burbujas de vigor."
	L["SpeedPosPointName"] = "Posición del velocímetro"
	L["SpeedPosPointTT"] = "Ajusta dónde está anclado el velocímetro en relación con la barra de vigor."
	L["Top"] = "Arriba"
	L["Bottom"] = "Abajo"
	L["Left"] = "Izquierda"
	L["Right"] = "Bien"
	L["SpeedPosXName"] = "Posición horizontal del velocímetro"
	L["SpeedPosXTT"] = "Ajuste la posición horizontal del velocímetro."
	L["SpeedPosYName"] = "Posición vertical del velocímetro"
	L["SpeedPosYTT"] = "Ajuste la posición vertical del velocímetro."
	L["SpeedScaleName"] = "Escala del velocímetro"
	L["SpeedScaleTT"] = "Ajuste la escala del velocímetro."
	L["Large"] = "Grande"
	L["Small"] = "Pequeño"
	L["Units"] = "Texto del velocímetro"
	L["UnitsTT"] = "Cambie las unidades que se muestran en el velocímetro.\n(Mecánicamente 1 metro = 1 yarda)"
	L["UnitsColor"] = "Color del texto del velocímetro"
	L["UnitYards"] = "yds/s"
	L["Yards"] = "Yardas"
	L["UnitMiles"] = "mph"
	L["Miles"] = "Millas"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "Metros"
	L["UnitKilometers"] = "k/h"
	L["Kilometers"] = "Kilómetros"
	L["UnitPercent"] = "%"
	L["Percent"] = "Porcentaje"
	L["SpeedTextScale"] = "Tamaño del texto del velocímetro"
	L["SpeedTextScaleTT"] = "Ajusta el tamaño del texto en el velocímetro."
	L["Version"] = "Versión %s"
	L["ResetAllSettings"] = "Restablecer todas las configuraciones de Dragon Rider"
	L["ResetAllSettingsTT"] = "Restablece todas las configuraciones específicamente para este complemento. Esto incluirá los valores de color personalizados."
	L["ResetAllSettingsConfirm"] = "¿Está seguro de que desea restablecer la configuración de Dragon Rider?"
	L["Low"] = "Bajo"
	L["High"] = "Alto"
	L["ProgressBar"] = "Velocímetro"
	L["ProgressBarColor"] = "Color del velocímetro"
	L["ColorPickerLowProgTT"] = "Elija un color personalizado para los valores de baja velocidad del velocímetro. Esto ocurre cuando el jugador no gana vigor."
	L["ColorPickerMidProgTT"] = "Elija un color personalizado para los valores de velocidad de vigor del velocímetro. Esto ocurre cuando el jugador gana vigor dentro de un rango de velocidad estándar."
	L["ColorPickerHighProgTT"] = "Elija un color personalizado para los valores de alta velocidad del velocímetro. Esto ocurre cuando el jugador está ganando vigor, pero está por encima del rango de velocidad estándar."
	L["ColorPickerLowTextTT"] = "Elija un color personalizado para los valores de baja velocidad del valor de velocidad. Esto ocurre cuando el jugador no gana vigor."
	L["ColorPickerMidTextTT"] = "Elija un color personalizado para los valores de velocidad de vigor del valor de velocidad. Esto ocurre cuando el jugador gana vigor dentro de un rango de velocidad estándar."
	L["ColorPickerHighTextTT"] = "Elija un color personalizado para los valores de alta velocidad del valor de velocidad. Esto ocurre cuando el jugador está ganando vigor, pero está por encima del rango de velocidad estándar."
	L["DragonridingTalents"] = "Talentos para montar dragones"
	L["OpenDragonridingTalents"] = "Talentos abiertos para montar dragones"
	L["OpenDragonridingTalentsTT"] = "Abrir ventana de talentos de montar dragón."
	L["SideArtName"] = "Arte Lateral"
	L["SideArtTT"] = "Alterna el arte en los lados de la barra principal de Vigor."
	L["BugfixesName"] = "Corrección de errores"
	L["BugfixesTT"] = "Intentos experimentales de corrección de errores cuando los marcos predeterminados de Blizzard no funcionan según lo previsto."
	L["BugfixHideVigor"] = "Fuerza Ocultar Vigor"
	L["BugfixHideVigorTT"] = "Fuerce la ocultación de la barra de vigor cuando esté desmontado y vuelva a mostrarla cuando esté montado en una montura voladora dinámica."
	L["FadeSpeedometer"] = "Velocímetro de desvanecimiento"
	L["FadeSpeedometerTT"] = "Alternar la atenuación del velocímetro cuando no se está planeando."
	L["ShowVigorTooltip"] = "Mostrar información sobre herramientas de vigor"
	L["ShowVigorTooltipTT"] = "Alternar la información sobre herramientas que se muestra en la barra de Vigor."
	L["FadeVigor"] = "Desvanecer vigor"
	L["FadeVigorTT"] = "Alternar el desvanecimiento de la barra de Vigor cuando no estás deslizándote y cuando tienes el Vigor máximo."
	L["LightningRush"] = "Orbes de carga estática"
	L["LightningRushTT"] = "Alternar marcos personalizados creados para auras de carga estática que son utilizadas por la habilidad Algarian Stormrider Lightning Rush."
	L["DynamicFOV"] = "Campo de visión dinámico"
	L["DynamicFOVTT"] = "Permite ajustar el campo de visión de la cámara según la velocidad de deslizamiento."
	L["Normal"] = "Normal"
	L["Advanced"] = "Avanzada"
	L["Reverse"] = "Inversa"
	L["Challenge"] = "Desafío"
	L["ReverseChallenge"] = "Desafío Inverso"
	L["Storm"] = "Tormenta"
	L["COMMAND_help"] = "ayuda"
	L["COMMAND_journal"] = "diario"
	L["COMMAND_listcommands"] = "Una lista de comandos:"
	L["COMMAND_dragonrider"] = "dragonrider"
	L["DragonRider"] = "Jinete de Dragones"
	L["RightClick_TT_Line"] = "Clic derecho: Abrir Configuración"
	L["LeftClick_TT_Line"] = "Clic izquierdo: Abrir Diario"
	L["SlashCommands_TT_Line"] = "'/dragonrider' para comandos adicionales"
	L["Score"] = "Puntuación"
	L["Guide"] = "Guía"
	L["Settings"] = "Configuración"
	L["ComingSoon"] = "Próximamente"
	L["UseAccountScores"] = "Usar Puntuaciones de la Cuenta"
	L["UseAccountScoresTT"] = "Esto mostrará los puntajes de carrera principales de tu cuenta en lugar de los puntajes de tu personaje. Los puntajes de la cuenta se indican con un asterisco (*)."
	L["PersonalBest"] = "Mejor Personal: "
	L["AccountBest"] = "Mejor de la Cuenta: "
	L["BestCharacter"] = "Mejor Personaje: "
	L["GoldTime"] = "Tiempo Oro: "
	L["SilverTime"] = "Tiempo Plata: "

return end

if LOCALE == "deDE" then
	-- German translations go here
	L["Vigor"] = "Kraft"
	L["Speedometer"] = "Tachometer"
	L["ToggleModelsName"] = "Vigor-Modelle anzeigen"
	L["ToggleModelsTT"] = "Zeigen Sie den wirbelnden Modelleffekt auf den Kraftblasen an."
	L["SpeedPosPointName"] = "Tachoposition"
	L["SpeedPosPointTT"] = "Passt an, wo der Tachometer relativ zur Kraftanzeige verankert ist."
	L["Top"] = "Spitze"
	L["Bottom"] = "Unten"
	L["Left"] = "Links"
	L["Right"] = "Rechts"
	L["SpeedPosXName"] = "Horizontale Position des Tachometers"
	L["SpeedPosXTT"] = "Passen Sie die horizontale Position des Tachometers an."
	L["SpeedPosYName"] = "Vertikale Position des Tachometers"
	L["SpeedPosYTT"] = "Passen Sie die vertikale Position des Tachometers an."
	L["SpeedScaleName"] = "Tachoskala"
	L["SpeedScaleTT"] = "Passen Sie die Skala des Tachometers an."
	L["Large"] = "Groß"
	L["Small"] = "Klein"
	L["Units"] = "Tachotext"
	L["UnitsTT"] = "Ändern Sie die auf dem Tachometer angezeigten Einheiten.\n(Mechanisch 1 Meter = 1 Yard)"
	L["UnitsColor"] = "Textfarbe des Tachometers"
	L["UnitYards"] = "yds/s"
	L["Yards"] = "Yards"
	L["UnitMiles"] = "mph"
	L["Miles"] = "Meilen"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "Meter"
	L["UnitKilometers"] = "km/h"
	L["Kilometers"] = "Kilometer"
	L["UnitPercent"] = "%"
	L["Percent"] = "Prozentsatz"
	L["SpeedTextScale"] = "Textgröße des Tachometers"
	L["SpeedTextScaleTT"] = "Passen Sie die Größe des Textes auf dem Tacho an."
	L["Version"] = "Version %s"
	L["ResetAllSettings"] = "Setzen Sie alle Dragon Rider-Einstellungen zurück"
	L["ResetAllSettingsTT"] = "Setzt alle Einstellungen speziell für dieses Add-on zurück. Dies schließt die benutzerdefinierten Farbwerte ein."
	L["ResetAllSettingsConfirm"] = "Sind Sie sicher, dass Sie die Einstellungen für Dragon Rider zurücksetzen möchten?"
	L["Low"] = "Niedrig"
	L["High"] = "Hoch"
	L["ProgressBar"] = "Tachometer"
	L["ProgressBarColor"] = "Tachofarbe"
	L["ColorPickerLowProgTT"] = "Wählen Sie eine benutzerdefinierte Farbe für die niedrigen Geschwindigkeitswerte des Tachos. Dies geschieht, wenn der Spieler keine Kraft gewinnt."
	L["ColorPickerMidProgTT"] = "Wählen Sie eine benutzerdefinierte Farbe für die Geschwindigkeitswerte des Tachometers. Dies geschieht, wenn der Spieler innerhalb eines normalen Geschwindigkeitsbereichs an Kraft gewinnt."
	L["ColorPickerHighProgTT"] = "Wählen Sie eine individuelle Farbe für die hohen Geschwindigkeitswerte des Tachos. Dies geschieht, wenn der Spieler an Kraft gewinnt, die Geschwindigkeit jedoch über dem Standardbereich liegt."
	L["ColorPickerLowTextTT"] = "Wählen Sie eine benutzerdefinierte Farbe für die niedrigen Geschwindigkeitswerte des Geschwindigkeitswerts. Dies geschieht, wenn der Spieler keine Kraft gewinnt."
	L["ColorPickerMidTextTT"] = "Wählen Sie eine benutzerdefinierte Farbe für die Kraftgeschwindigkeitswerte des Geschwindigkeitswerts. Dies geschieht, wenn der Spieler innerhalb eines normalen Geschwindigkeitsbereichs an Kraft gewinnt."
	L["ColorPickerHighTextTT"] = "Wählen Sie eine benutzerdefinierte Farbe für die hohen Geschwindigkeitswerte des Geschwindigkeitswerts. Dies geschieht, wenn der Spieler an Kraft gewinnt, die Geschwindigkeit jedoch über dem Standardbereich liegt."
	L["DragonridingTalents"] = "Drachenreitende Talente"
	L["OpenDragonridingTalents"] = "Öffnen Sie Drachenreiten-Talente"
	L["OpenDragonridingTalentsTT"] = "Öffnen Sie das Fenster Drachenreiten-Talente."
	L["SideArtName"] = "Seitenkunst"
	L["SideArtTT"] = "Schalten Sie die Grafik an den Seiten der Haupt-Vigor-Leiste um."
	L["BugfixesName"] = "Fehlerbehebung"
	L["BugfixesTT"] = "Experimentelle Fehlerbehebungsversuche für den Fall, dass Standard-Blizzard-Frames nicht wie vorgesehen funktionieren."
	L["BugfixHideVigor"] = "Force Hide Vigor"
	L["BugfixHideVigorTT"] = "Erzwingen Sie das Ausblenden der Energieleiste beim Absteigen und das erneute Einblenden, wenn Sie auf einem dynamischen Flugreittier montiert sind."
	L["FadeSpeedometer"] = "Fade Speedometer"
	L["FadeSpeedometerTT"] = "Ausblenden des Tachometers ein-/ausschalten, wenn nicht gleitend."
	L["ShowVigorTooltip"] = "Vigor-Tooltip anzeigen"
	L["ShowVigorTooltipTT"] = "Schaltet den Tooltip um, der auf der Kraftleiste angezeigt wird."
	L["FadeVigor"] = "Fade Vigor"
	L["FadeVigorTT"] = "Ausblenden der Kraftleiste ein-/ausschalten, wenn nicht gleitend und bei voller Kraft."
	L["LightningRush"] = "Statische Ladungskugeln"
	L["LightningRushTT"] = "Schalten Sie die benutzerdefinierten Rahmen um, die für statische Ladungsauren erstellt wurden, die von der Algarian Stormrider Lightning Rush-Fähigkeit verwendet werden."
	L["DynamicFOV"] = "Dynamisches Sichtfeld"
	L["DynamicFOVTT"] = "Ermöglicht die Anpassung des Kamerasichtfelds basierend auf der Gleitgeschwindigkeit."
	L["Normal"] = "Normal"
	L["Advanced"] = "Fortgeschritten"
	L["Reverse"] = "Umgekehrt"
	L["Challenge"] = "Herausforderung"
	L["ReverseChallenge"] = "Umgekehrte Herausforderung"
	L["Storm"] = "Sturm"
	L["COMMAND_help"] = "hilfe"
	L["COMMAND_journal"] = "tagebuch"
	L["COMMAND_listcommands"] = "Eine Liste der Befehle:"
	L["COMMAND_dragonrider"] = "drachenreiter"
	L["DragonRider"] = "Drachenreiter"
	L["RightClick_TT_Line"] = "Rechtsklick: Einstellungen öffnen"
	L["LeftClick_TT_Line"] = "Linksklick: Tagebuch öffnen"
	L["SlashCommands_TT_Line"] = "'/drachenreiter' für weitere Befehle"
	L["Score"] = "Punktzahl"
	L["Guide"] = "Anleitung"
	L["Settings"] = "Einstellungen"
	L["ComingSoon"] = "Demnächst"
	L["UseAccountScores"] = "Benutze Account-Wertungen"
	L["UseAccountScoresTT"] = "Dies zeigt deine besten Rennpunkte für das Konto an, anstelle der Punkte deines Charakters. Punkte des Kontos werden mit einem Stern (*) markiert."
	L["PersonalBest"] = "Persönlicher Rekord: "
	L["AccountBest"] = "Konto-Bester: "
	L["BestCharacter"] = "Bester Charakter: "
	L["GoldTime"] = "Goldzeit: "
	L["SilverTime"] = "Silberzeit: "

return end

if LOCALE == "frFR" then
	-- French translations go here
	L["Vigor"] = "Vigueur"
	L["Speedometer"] = "Compteur de vitesse"
	L["ToggleModelsName"] = "Afficher les modèles de vigueur"
	L["ToggleModelsTT"] = "Affichez l'effet de modèle tourbillonnant sur les bulles de vigueur."
	L["SpeedPosPointName"] = "Position du compteur de vitesse"
	L["SpeedPosPointTT"] = "Ajuste l'endroit où le compteur de vitesse est ancré par rapport à la barre de vigueur."
	L["Top"] = "Haut"
	L["Bottom"] = "Bas"
	L["Left"] = "Gauche"
	L["Right"] = "Droite"
	L["SpeedPosXName"] = "Position horizontale du compteur de vitesse"
	L["SpeedPosXTT"] = "Réglez la position horizontale du compteur de vitesse."
	L["SpeedPosYName"] = "Position verticale du compteur de vitesse"
	L["SpeedPosYTT"] = "Réglez la position verticale du compteur de vitesse."
	L["SpeedScaleName"] = "Échelle du compteur de vitesse"
	L["SpeedScaleTT"] = "Réglez l'échelle du compteur de vitesse."
	L["Large"] = "Grand"
	L["Small"] = "Petit"
	L["Units"] = "Texte du compteur de vitesse"
	L["UnitsTT"] = "Modifiez les unités affichées sur le compteur de vitesse.\n(Mécaniquement 1 mètre = 1 yard)"
	L["UnitsColor"] = "Couleur du texte du compteur de vitesse"
	L["UnitYards"] = "verges/s"
	L["Yards"] = "Verges"
	L["UnitMiles"] = "mi/h"
	L["Miles"] = "Milles"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "Mètres"
	L["UnitKilometers"] = "km/h"
	L["Kilometers"] = "Kilomètres"
	L["UnitPercent"] = "%"
	L["Percent"] = "Pourcentage"
	L["SpeedTextScale"] = "Taille du texte du compteur de vitesse"
	L["SpeedTextScaleTT"] = "Ajustez la taille du texte sur le compteur de vitesse."
	L["Version"] = "Version %s"
	L["ResetAllSettings"] = "Réinitialiser tous les paramètres de Dragon Rider"
	L["ResetAllSettingsTT"] = "Réinitialise tous les paramètres spécifiquement pour cet addon. Cela inclura les valeurs de couleur personnalisées."
	L["ResetAllSettingsConfirm"] = "Voulez-vous vraiment réinitialiser les paramètres de Dragon Rider ?"
	L["Low"] = "Faible"
	L["High"] = "Haut"
	L["ProgressBar"] = "Compteur de vitesse"
	L["ProgressBarColor"] = "Couleur du compteur de vitesse"
	L["ColorPickerLowProgTT"] = "Choisissez une couleur personnalisée pour les valeurs de basse vitesse du compteur de vitesse. Cela se produit lorsque le joueur ne gagne aucune vigueur."
	L["ColorPickerMidProgTT"] = "Choisissez une couleur personnalisée pour les valeurs de vitesse de vigueur du compteur de vitesse. Cela se produit lorsque le joueur gagne en vigueur dans une plage de vitesse standard."
	L["ColorPickerHighProgTT"] = "Choisissez une couleur personnalisée pour les valeurs de vitesse élevée du compteur de vitesse. Cela se produit lorsque le joueur gagne en vigueur, mais est au-dessus de la plage de vitesse standard."
	L["ColorPickerLowTextTT"] = "Choisissez une couleur personnalisée pour les valeurs de faible vitesse de la valeur de vitesse. Cela se produit lorsque le joueur ne gagne aucune vigueur."
	L["ColorPickerMidTextTT"] = "Choisissez une couleur personnalisée pour les valeurs de vitesse de vigueur de la valeur de vitesse. Cela se produit lorsque le joueur gagne en vigueur dans une plage de vitesse standard."
	L["ColorPickerHighTextTT"] = "Choisissez une couleur personnalisée pour les valeurs de vitesse élevée de la valeur de vitesse. Cela se produit lorsque le joueur gagne en vigueur, mais est au-dessus de la plage de vitesse standard."
	L["DragonridingTalents"] = "Talents de chevauchée de dragon"
	L["OpenDragonridingTalents"] = "Ouvrir les talents de chevaucheur de dragon"
	L["OpenDragonridingTalentsTT"] = "Ouvrez la fenêtre des talents de Dragonriding."
	L["SideArtName"] = "Art Parallèle"
	L["SideArtTT"] = "Basculez l’art sur les côtés de la barre Vigor principale."
	L["BugfixesName"] = "Corrections de bugs"
	L["BugfixesTT"] = "Tentatives expérimentales de correction de bogues lorsque les images Blizzard par défaut ne fonctionnent pas comme prévu."
	L["BugfixHideVigor"] = "Forcer à masquer la vigueur"
	L["BugfixHideVigorTT"] = "Forcer à masquer la barre de vigueur une fois démonté et à la réafficher lorsqu'il est monté sur une monture volante dynamique."
	L["FadeSpeedometer"] = "Fade Speedometer"
	L["FadeSpeedometerTT"] = "Activer le fondu du compteur de vitesse lorsque vous ne planez pas."
	L["ShowVigorTooltip"] = "Afficher l'info-bulle Vigor"
	L["ShowVigorTooltipTT"] = "Basculez l'info-bulle qui s'affiche sur la barre Vigor."
	L["FadeVigor"] = "Fade Vigor"
	L["FadeVigorTT"] = "Activer l'effacement de la barre Vigor lorsque vous ne glissez pas et lorsque vous êtes au maximum de Vigor."
	L["LightningRush"] = "Orbes de charge statique"
	L["LightningRushTT"] = "Activez les cadres personnalisés conçus pour les auras de charge statique qui sont utilisées par la capacité Algarian Stormrider Lightning Rush."
	L["DynamicFOV"] = "Champ de vision dynamique"
	L["DynamicFOVTT"] = "Permet d'ajuster le champ de vision de la caméra en fonction de la vitesse de glisse."
	L["Normal"] = "Normale"
	L["Advanced"] = "Avancée"
	L["Reverse"] = "Inversée"
	L["Challenge"] = "Défi"
	L["ReverseChallenge"] = "Défi Inversé"
	L["Storm"] = "Tempête"
	L["COMMAND_help"] = "aide"
	L["COMMAND_journal"] = "journal"
	L["COMMAND_listcommands"] = "Liste des commandes :"
	L["COMMAND_dragonrider"] = "dragonrider"
	L["DragonRider"] = "Chevaucheur de dragon"
	L["RightClick_TT_Line"] = "Clic droit : Ouvrir les paramètres"
	L["LeftClick_TT_Line"] = "Clic gauche : Ouvrir le journal"
	L["SlashCommands_TT_Line"] = "'/dragonrider' pour des commandes supplémentaires"
	L["Score"] = "Score"
	L["Guide"] = "Guide"
	L["Settings"] = "Paramètres"
	L["ComingSoon"] = "Prochainement"
	L["UseAccountScores"] = "Utiliser les Scores du Compte"
	L["UseAccountScoresTT"] = "Cela affichera vos meilleures scores de courses du compte plutôt que ceux de votre personnage. Les scores du compte sont indiqués par un astérisque (*)."
	L["PersonalBest"] = "Meilleur personnel : "
	L["AccountBest"] = "Meilleur du compte : "
	L["BestCharacter"] = "Meilleur personnage : "
	L["GoldTime"] = "Temps Or : "
	L["SilverTime"] = "Temps Argent : "

return end

if LOCALE == "itIT" then
	-- French translations go here
	L["Vigor"] = "Vigore"
	L["Speedometer"] = "Tachimetro"
	L["ToggleModelsName"] = "Mostra modelli di vigore"
	L["ToggleModelsTT"] = "Mostra l'effetto del modello vorticoso sulle bolle di vigore."
	L["SpeedPosPointName"] = "Posizione del tachimetro"
	L["SpeedPosPointTT"] = "Regola dove è ancorato il tachimetro rispetto alla barra del vigore."
	L["Top"] = "Superiore"
	L["Bottom"] = "Metter il fondo a"
	L["Left"] = "Sinistra"
	L["Right"] = "Giusto"
	L["SpeedPosXName"] = "Posizione orizzontale del tachimetro"
	L["SpeedPosXTT"] = "Regola la posizione orizzontale del tachimetro."
	L["SpeedPosYName"] = "Posizione verticale del tachimetro"
	L["SpeedPosYTT"] = "Regola la posizione verticale del tachimetro."
	L["SpeedScaleName"] = "Scala del tachimetro"
	L["SpeedScaleTT"] = "Regola la scala del tachimetro."
	L["Large"] = "Grande"
	L["Small"] = "Piccolo"
	L["Units"] = "Testo del tachimetro"
	L["UnitsTT"] = "Cambia le unità visualizzate sul tachimetro.\n(Meccanicamente 1 metro = 1 iarda)"
	L["UnitsColor"] = "Colore del testo del tachimetro"
	L["UnitYards"] = "yd/s"
	L["Yards"] = "Iarde"
	L["UnitMiles"] = "mph"
	L["Miles"] = "Miglia"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "Metri"
	L["UnitKilometers"] = "km/h"
	L["Kilometers"] = "Chilometri"
	L["UnitPercent"] = "%"
	L["Percent"] = "Percentuale"
	L["SpeedTextScale"] = "Dimensione del testo del tachimetro"
	L["SpeedTextScaleTT"] = "Regola la dimensione del testo sul tachimetro."
	L["Version"] = "Versione %s"
	L["ResetAllSettings"] = "Ripristina tutte le impostazioni di Dragon Rider"
	L["ResetAllSettingsTT"] = "Ripristina tutte le impostazioni specifiche per questo componente aggiuntivo. Ciò includerà i valori di colore personalizzati."
	L["ResetAllSettingsConfirm"] = "Sei sicuro di voler ripristinare le impostazioni di Dragon Rider?"
	L["Low"] = "Basso"
	L["High"] = "Alto"
	L["ProgressBar"] = "Tachimetro"
	L["ProgressBarColor"] = "Colore del tachimetro"
	L["ColorPickerLowProgTT"] = "Scegli un colore personalizzato per i valori di bassa velocità del tachimetro. Ciò si verifica quando il giocatore non sta guadagnando vigore."
	L["ColorPickerMidProgTT"] = "Scegli un colore personalizzato per i valori di velocità del vigore del tachimetro. Ciò si verifica quando il giocatore sta guadagnando vigore entro un intervallo di velocità standard."
	L["ColorPickerHighProgTT"] = "Scegli un colore personalizzato per i valori di alta velocità del tachimetro. Ciò si verifica quando il giocatore sta guadagnando vigore, ma è al di sopra della gamma di velocità standard."
	L["ColorPickerLowTextTT"] = "Scegli un colore personalizzato per i valori di bassa velocità del valore di velocità. Ciò si verifica quando il giocatore non sta guadagnando vigore."
	L["ColorPickerMidTextTT"] = "Scegli un colore personalizzato per i valori di velocità del vigore del valore di velocità. Ciò si verifica quando il giocatore sta guadagnando vigore entro un intervallo di velocità standard."
	L["ColorPickerHighTextTT"] = "Scegli un colore personalizzato per i valori ad alta velocità del valore della velocità. Ciò si verifica quando il giocatore sta guadagnando vigore, ma è al di sopra della gamma di velocità standard."
	L["DragonridingTalents"] = "Talenti di Cavalcadraghi"
	L["OpenDragonridingTalents"] = "Apri Talenti di cavalcatura del drago"
	L["OpenDragonridingTalentsTT"] = "Apri la finestra dei talenti di cavalcatura del drago."
	L["SideArtName"] = "Arte Laterale"
	L["SideArtTT"] = "Attiva/disattiva la grafica sui lati della barra principale del Vigore."
	L["BugfixesName"] = "Correzioni di bug"
	L["BugfixesTT"] = "Tentativi sperimentali di correzione di bug per quando i frame Blizzard predefiniti non funzionano come previsto."
	L["BugfixHideVigor"] = "Forza Nascondi Vigore"
	L["BugfixHideVigorTT"] = "Nascondi forzatamente la barra del vigore quando scendi e la mostri quando sei montata su una cavalcatura volante dinamica."
	L["FadeSpeedometer"] = "Tachimetro della dissolvenza"
	L["FadeSpeedometerTT"] = "Attiva/disattiva la dissolvenza del tachimetro quando non stai planando."
	L["ShowVigorTooltip"] = "Mostra descrizione comando Vigor"
	L["ShowVigorTooltipTT"] = "Attiva/disattiva la descrizione comando visualizzata sulla barra del vigore."
	L["FadeVigor"] = "Vigore della dissolvenza"
	L["FadeVigorTT"] = "Attiva/disattiva la dissolvenza della barra del vigore quando non si plana e mentre si è al massimo del vigore."
	L["LightningRush"] = "Sfere di carica statica"
	L["LightningRushTT"] = "Attiva/disattiva i frame personalizzati realizzati per le aure di carica statica utilizzate dall'abilità Algarian Stormrider Lightning Rush."
	L["DynamicFOV"] = "FOV dinamico"
	L["DynamicFOVTT"] = "Consente la regolazione del campo visivo della telecamera in base alla velocità di planata."
	L["Normal"] = "Normale"
	L["Advanced"] = "Avanzate"
	L["Reverse"] = "Inverso"
	L["Challenge"] = "Sfida"
	L["ReverseChallenge"] = "Sfida Inversa"
	L["Storm"] = "Tempesta"
	L["COMMAND_help"] = "aiuto"
	L["COMMAND_journal"] = "diario"
	L["COMMAND_listcommands"] = "Lista dei comandi:"
	L["COMMAND_dragonrider"] = "dragonrider"
	L["DragonRider"] = "Cavaliere del Drago"
	L["RightClick_TT_Line"] = "Clic destro: Apri impostazioni"
	L["LeftClick_TT_Line"] = "Clic sinistro: Apri diario"
	L["SlashCommands_TT_Line"] = "'/dragonrider' per comandi aggiuntivi"
	L["Score"] = "Punteggio"
	L["Guide"] = "Guida"
	L["Settings"] = "Impostazioni"
	L["ComingSoon"] = "Prossimamente"
	L["UseAccountScores"] = "Usa Punteggi dell'Account"
	L["UseAccountScoresTT"] = "Questo mostrerà i tuoi migliori punteggi di gara dell'account invece di quelli del tuo personaggio. I punteggi dell'account sono indicati con un asterisco (*)."
	L["PersonalBest"] = "Personale migliore: "
	L["AccountBest"] = "Miglior dell'account: "
	L["BestCharacter"] = "Miglior personaggio: "
	L["GoldTime"] = "Tempo Oro: "
	L["SilverTime"] = "Tempo Argento: "

return end

if LOCALE == "ptBR" then
	-- Brazilian Portuguese translations go here
	L["Vigor"] = "Vigor"
	L["Speedometer"] = "Velocímetro"
	L["ToggleModelsName"] = "Mostrar modelos de vigor"
	L["ToggleModelsTT"] = "Exiba o efeito do modelo giratório nas bolhas de vigor."
	L["SpeedPosPointName"] = "Posição do velocímetro"
	L["SpeedPosPointTT"] = "Ajusta onde o velocímetro está ancorado em relação à barra de vigor."
	L["Top"] = "Principal"
	L["Bottom"] = "Fundo"
	L["Left"] = "Esquerda"
	L["Right"] = "Certo"
	L["SpeedPosXName"] = "Posição horizontal do velocímetro"
	L["SpeedPosXTT"] = "Ajuste a posição horizontal do velocímetro."
	L["SpeedPosYName"] = "Posição vertical do velocímetro"
	L["SpeedPosYTT"] = "Ajuste a posição vertical do velocímetro."
	L["SpeedScaleName"] = "Escala do velocímetro"
	L["SpeedScaleTT"] = "Ajuste a escala do velocímetro."
	L["Large"] = "Grande"
	L["Small"] = "Pequeno"
	L["Units"] = "Texto do velocímetro"
	L["UnitsTT"] = "Altere as unidades exibidas no velocímetro.\n(mecanicamente 1 metro = 1 jarda)"
	L["UnitsColor"] = "Cor do texto do velocímetro"
	L["UnitYards"] = "jardas/s"
	L["Yards"] = "Jardas"
	L["UnitMiles"] = "mph"
	L["Miles"] = "Milhas"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "Metros"
	L["UnitKilometers"] = "km/h"
	L["Kilometers"] = "Quilômetros"
	L["UnitPercent"] = "%"
	L["Percent"] = "Percentagem"
	L["SpeedTextScale"] = "Tamanho do texto do velocímetro"
	L["SpeedTextScaleTT"] = "Ajuste o tamanho do texto no velocímetro."
	L["Version"] = "Versão %s"
	L["ResetAllSettings"] = "Redefinir todas as configurações do Dragon Rider"
	L["ResetAllSettingsTT"] = "Redefine todas as configurações especificamente para este complemento. Isso incluirá os valores de cores personalizados."
	L["ResetAllSettingsConfirm"] = "Tem certeza de que deseja redefinir as configurações do Dragon Rider?"
	L["Low"] = "Baixo"
	L["High"] = "Alto"
	L["ProgressBar"] = "Velocímetro"
	L["ProgressBarColor"] = "Cor do velocímetro"
	L["ColorPickerLowProgTT"] = "Escolha uma cor personalizada para os valores de baixa velocidade do velocímetro. Isso ocorre quando o jogador não está ganhando vigor."
	L["ColorPickerMidProgTT"] = "Escolha uma cor personalizada para os valores de velocidade de vigor do velocímetro. Isso ocorre quando o jogador está ganhando vigor dentro de uma faixa de velocidade padrão."
	L["ColorPickerHighProgTT"] = "Escolha uma cor personalizada para os valores de alta velocidade do velocímetro. Isso ocorre quando o jogador está ganhando vigor, mas está acima da faixa de velocidade padrão."
	L["ColorPickerLowTextTT"] = "Escolha uma cor personalizada para os valores de velocidade baixa do valor de velocidade. Isso ocorre quando o jogador não está ganhando vigor."
	L["ColorPickerMidTextTT"] = "Escolha uma cor personalizada para os valores de velocidade de vigor do valor de velocidade. Isso ocorre quando o jogador está ganhando vigor dentro de uma faixa de velocidade padrão."
	L["ColorPickerHighTextTT"] = "Escolha uma cor personalizada para os valores de alta velocidade do valor de velocidade. Isso ocorre quando o jogador está ganhando vigor, mas está acima da faixa de velocidade padrão."
	L["DragonridingTalents"] = "Talenti di cavalcatura del drago"
	L["OpenDragonridingTalents"] = "Apri Talenti di cavalcatura del drago"
	L["OpenDragonridingTalentsTT"] = "Apri la finestra dei talenti di cavalcatura del drago."
	L["SideArtName"] = "Arte Lateral"
	L["SideArtTT"] = "Alterne a arte nas laterais da barra principal do Vigor."
	L["BugfixesName"] = "Correções de bugs"
	L["BugfixesTT"] = "Tentativas experimentais de correção de bugs quando os frames padrão da Blizzard não estão funcionando conforme o esperado."
	L["BugfixHideVigor"] = "Forçar Ocultar Vigor"
	L["BugfixHideVigorTT"] = "Force a ocultação da barra de vigor quando desmontada e mostre-a novamente quando montada em uma montaria voadora dinâmica."
	L["FadeSpeedometer"] = "Fade Velocímetro"
	L["FadeSpeedometerTT"] = "Alternar o desbotamento do velocímetro quando não estiver planando."
	L["ShowVigorTooltip"] = "Mostrar dica de vigor"
	L["ShowVigorTooltipTT"] = "Alternar a dica de ferramenta exibida na barra de Vigor."
	L["FadeVigor"] = "Fade Vigor"
	L["FadeVigorTT"] = "Alternar o desvanecimento da barra de Vigor quando não estiver planando e enquanto estiver com Vigor total."
	L["LightningRush"] = "Orbes de carga estática"
	L["LightningRushTT"] = "Alternar molduras personalizadas feitas para auras Static Charge que são usadas pela habilidade Algarian Stormrider Lightning Rush."
	L["DynamicFOV"] = "Campo de visão dinâmico"
	L["DynamicFOVTT"] = "Permite o ajuste do campo de visão da câmera com base na velocidade de planeio."
	L["Normal"] = "Normal"
	L["Advanced"] = "Avançada"
	L["Reverse"] = "Invertida"
	L["Challenge"] = "Desafio"
	L["ReverseChallenge"] = "Desafio Invertida"
	L["Storm"] = "Tempestade"
	L["COMMAND_help"] = "ajuda"
	L["COMMAND_journal"] = "diário"
	L["COMMAND_listcommands"] = "Lista de comandos:"
	L["COMMAND_dragonrider"] = "dragonrider"
	L["DragonRider"] = "Cavaleiro do Dragão"
	L["RightClick_TT_Line"] = "Clique Direito: Abrir Configurações"
	L["LeftClick_TT_Line"] = "Clique Esquerdo: Abrir Diário"
	L["SlashCommands_TT_Line"] = "'/dragonrider' para comandos adicionais"
	L["Score"] = "Pontuação"
	L["Guide"] = "Guia"
	L["Settings"] = "Configurações"
	L["ComingSoon"] = "Em Breve"
	L["UseAccountScores"] = "Usar Pontuações da Conta"
	L["UseAccountScoresTT"] = "Isso mostrará suas melhores pontuações de corrida da conta em vez das pontuações do seu personagem. As pontuações da conta são indicadas com um asterisco (*)."
	L["PersonalBest"] = "Melhor Pessoal: "
	L["AccountBest"] = "Melhor da Conta: "
	L["BestCharacter"] = "Melhor Personagem: "
	L["GoldTime"] = "Tempo Ouro: "
	L["SilverTime"] = "Tempo Prata: "

-- Note that the EU Portuguese WoW client also
-- uses the Brazilian Portuguese locale code.
return end

if LOCALE == "ruRU" then
	-- Russian translations go here
	L["Vigor"] = "Энергия"
	L["Speedometer"] = "Спидометр"
	L["ToggleModelsName"] = "Показать модели энергии"
	L["ToggleModelsTT"] = "Отобразите эффект вращающейся модели на пузырьках энергии."
	L["SpeedPosPointName"] = "Положение спидометра"
	L["SpeedPosPointTT"] = "Регулирует место крепления спидометра относительно шкалы мощности."
	L["Top"] = "Вершина"
	L["Bottom"] = "Нижний"
	L["Left"] = "Левый"
	L["Right"] = "Верно"
	L["SpeedPosXName"] = "Горизонтальное положение спидометра"
	L["SpeedPosXTT"] = "Отрегулируйте горизонтальное положение спидометра."
	L["SpeedPosYName"] = "Вертикальное положение спидометра"
	L["SpeedPosYTT"] = "Отрегулируйте вертикальное положение спидометра."
	L["SpeedScaleName"] = "Шкала спидометра"
	L["SpeedScaleTT"] = "Отрегулируйте шкалу спидометра."
	L["Large"] = "Большой"
	L["Small"] = "Маленький"
	L["Units"] = "Текст спидометра"
	L["UnitsTT"] = "Измените единицы измерения, отображаемые на спидометре.\n(Механически 1 метр = 1 ярд)"
	L["UnitsColor"] = "Цвет текста спидометра"
	L["UnitYards"] = "ярдов/с"
	L["Yards"] = "Дворы"
	L["UnitMiles"] = "миль в час"
	L["Miles"] = "Мили"
	L["UnitMeters"] = "м/с"
	L["Meters"] = "Метры"
	L["UnitKilometers"] = "км/ч"
	L["Kilometers"] = "км"
	L["UnitPercent"] = "%"
	L["Percent"] = "Процент"
	L["SpeedTextScale"] = "Размер текста спидометра"
	L["SpeedTextScaleTT"] = "Отрегулируйте размер текста на спидометре."
	L["Version"] = "Версия %s"
	L["ResetAllSettings"] = "Сбросить все настройки Dragon Rider"
	L["ResetAllSettingsTT"] = "Сбрасывает все настройки специально для этого аддона. Это будет включать пользовательские значения цвета."
	L["ResetAllSettingsConfirm"] = "Вы уверены, что хотите сбросить настройки Dragon Rider?"
	L["Low"] = "Низкий"
	L["High"] = "Высокий"
	L["ProgressBar"] = "Спидометр"
	L["ProgressBarColor"] = "Цвет спидометра"
	L["ColorPickerLowProgTT"] = "Выберите собственный цвет для значений низкой скорости спидометра. Это происходит, когда игрок не набирает сил."
	L["ColorPickerMidProgTT"] = "Выберите собственный цвет для значений скорости энергии спидометра. Это происходит, когда игрок набирает силу в пределах стандартного диапазона скоростей."
	L["ColorPickerHighProgTT"] = "Выберите собственный цвет для значений высокой скорости спидометра. Это происходит, когда игрок набирает силу, но его скорость выше стандартного диапазона."
	L["ColorPickerLowTextTT"] = "Выберите пользовательский цвет для значений низкой скорости значения скорости. Это происходит, когда игрок не набирает сил."
	L["ColorPickerMidTextTT"] = "Выберите пользовательский цвет для значений скорости силы значения скорости. Это происходит, когда игрок набирает силу в пределах стандартного диапазона скоростей."
	L["ColorPickerHighTextTT"] = "Выберите пользовательский цвет для высокоскоростных значений значения скорости. Это происходит, когда игрок набирает силу, но его скорость выше стандартного диапазона."
	L["DragonridingTalents"] = "Таланты верховой езды на драконах"
	L["OpenDragonridingTalents"] = "Открытые таланты верховой езды на драконах"
	L["OpenDragonridingTalentsTT"] = "Откройте окно талантов верховой езды на драконах."
	L["SideArtName"] = "Боковой арт"
	L["SideArtTT"] = "Переключите изображение по бокам главной панели Vigor."
	L["BugfixesName"] = "Исправление ошибок"
	L["BugfixesTT"] = "Экспериментальные попытки исправить ошибку, когда стандартные фреймы Blizzard не работают должным образом."
	L["BugfixHideVigor"] = "Сила Скрыть Энергию"
	L["BugfixHideVigorTT"] = "Принудительно скройте шкалу энергии при спешивании и снова отобразите ее при установке на динамического летающего средства передвижения."
	L["FadeSpeedometer"] = "Затухание спидометра"
	L["FadeSpeedometerTT"] = "Включить затухание спидометра, когда он не скользит."
	L["ShowVigorTooltip"] = "Показать подсказку по Vigor"
	L["ShowVigorTooltipTT"] = "Переключить всплывающую подсказку, отображаемую на шкале энергии."
	L["FadeVigor"] = "Угасание энергии"
	L["FadeVigorTT"] = "Переключить затухание шкалы Энергии, когда она не скользит и при полной Энергии."
	L["LightningRush"] = "Сферы статического заряда"
	L["LightningRushTT"] = "Переключить пользовательские рамки, созданные для аур статического заряда, которые используются способностью Молниеносный рывок Алгарского всадника бури."
	L["DynamicFOV"] = "Динамический угол обзора"
	L["DynamicFOVTT"] = "Позволяет регулировать поле зрения камеры в зависимости от скорости планирования."
	L["Normal"] = "Нормальный"
	L["Advanced"] = "высокая сложность"
	L["Reverse"] = "обратный маршрут"
	L["Challenge"] = "испытание"
	L["ReverseChallenge"] = "обратный маршрут"
	L["Storm"] = "Буря"
	L["COMMAND_help"] = "помощь"
	L["COMMAND_journal"] = "журнал"
	L["COMMAND_listcommands"] = "Список команд:"
	L["COMMAND_dragonrider"] = "всадникдракона"
	L["DragonRider"] = "Драконий Всадник"
	L["RightClick_TT_Line"] = "Правый клик: Открыть настройки"
	L["LeftClick_TT_Line"] = "Левый клик: Открыть журнал"
	L["SlashCommands_TT_Line"] = "'/всадникдракона' для дополнительных команд"
	L["Score"] = "Счёт"
	L["Guide"] = "Руководство"
	L["Settings"] = "Настройки"
	L["ComingSoon"] = "Скоро"
	L["UseAccountScores"] = "Использовать Счета аккаунта"
	L["UseAccountScoresTT"] = "Это отобразит ваши лучшие результаты гонок аккаунта вместо результатов вашего персонажа. Результаты аккаунта обозначаются звездочкой (*)."
	L["PersonalBest"] = "Личный лучший: "
	L["AccountBest"] = "Лучший аккаунта: "
	L["BestCharacter"] = "Лучший персонаж: "
	L["GoldTime"] = "Золотое время: "
	L["SilverTime"] = "Серебряное время: "


return end

if LOCALE == "koKR" then
	-- Korean translations go here
	L["Vigor"] = "활기"
	L["Speedometer"] = "속도계"
	L["ToggleModelsName"] = "활기 모델 표시"
	L["ToggleModelsTT"] = "활력 거품에 소용돌이 모델 효과를 표시합니다."
	L["SpeedPosPointName"] = "속도계 위치"
	L["SpeedPosPointTT"] = "활력 막대를 기준으로 속도계가 고정되는 위치를 조정합니다."
	L["Top"] = "맨 위"
	L["Bottom"] = "맨 아래"
	L["Left"] = "왼쪽"
	L["Right"] = "오른쪽"
	L["SpeedPosXName"] = "속도계 수평 위치"
	L["SpeedPosXTT"] = "속도계의 수평 위치를 조정합니다."
	L["SpeedPosYName"] = "속도계 수직 위치"
	L["SpeedPosYTT"] = "속도계의 수직 위치를 조정하십시오."
	L["SpeedScaleName"] = "속도계 눈금"
	L["SpeedScaleTT"] = "속도계의 눈금을 조정하십시오."
	L["Large"] = "크기가 큰"
	L["Small"] = "작은"
	L["Units"] = "속도계 텍스트"
	L["UnitsTT"] = "속도계에 표시되는 단위를 변경합니다.\n(기계적으로 1미터 = 1야드)"
	L["UnitsColor"] = "속도계 텍스트 색상"
	L["UnitYards"] = "야드/초"
	L["Yards"] = "야드"
	L["UnitMiles"] = "시간 당 마일"
	L["Miles"] = "마일"
	L["UnitMeters"] = "m/s"
	L["Meters"] = "미터"
	L["UnitKilometers"] = "km/h"
	L["Kilometers"] = "킬로미터"
	L["UnitPercent"] = "%"
	L["Percent"] = "백분율"
	L["SpeedTextScale"] = "속도계 텍스트 크기"
	L["SpeedTextScaleTT"] = "속도계의 텍스트 크기를 조정합니다."
	L["Version"] = "버전 %s"
	L["ResetAllSettings"] = "모든 드래곤 라이더 설정 재설정"
	L["ResetAllSettingsTT"] = "이 애드온에 대한 모든 설정을 재설정합니다. 여기에는 사용자 정의 색상 값이 포함됩니다."
	L["ResetAllSettingsConfirm"] = "Dragon Rider의 설정을 재설정하시겠습니까?"
	L["Low"] = "낮은"
	L["High"] = "높은"
	L["ProgressBar"] = "속도계"
	L["ProgressBarColor"] = "속도계 색상"
	L["ColorPickerLowProgTT"] = "속도계의 저속 값에 대한 사용자 정의 색상을 선택하십시오. 이것은 플레이어가 활력을 얻지 못할 때 발생합니다."
	L["ColorPickerMidProgTT"] = "속도계의 활력 속도 값에 대한 사용자 정의 색상을 선택하십시오. 이것은 플레이어가 표준 a 속도 범위 내에서 활력을 얻고 있을 때 발생합니다."
	L["ColorPickerHighProgTT"] = "속도계의 고속 값에 대한 사용자 정의 색상을 선택하십시오. 이것은 플레이어가 활력을 얻고 있지만 표준 속도 범위를 초과할 때 발생합니다."
	L["ColorPickerLowTextTT"] = "속도 값의 저속 값에 대한 사용자 지정 색상을 선택합니다. 이것은 플레이어가 활력을 얻지 못할 때 발생합니다."
	L["ColorPickerMidTextTT"] = "속도 값의 활력 속도 값에 대한 사용자 정의 색상을 선택하십시오. 이것은 플레이어가 표준 a 속도 범위 내에서 활력을 얻고 있을 때 발생합니다."
	L["ColorPickerHighTextTT"] = "속도 값의 고속 값에 대한 사용자 지정 색상을 선택합니다. 이것은 플레이어가 활력을 얻고 있지만 표준 속도 범위를 초과할 때 발생합니다."
	L["DragonridingTalents"] = "용 타기 재능"
	L["OpenDragonridingTalents"] = "용 타기 재능 공개"
	L["OpenDragonridingTalentsTT"] = "용 타기 특성 창을 엽니다."
	L["SideArtName"] = "사이드 아트"
	L["SideArtTT"] = "메인 Vigor 바의 측면에 있는 아트를 전환합니다."
	L["BugfixesName"] = "버그 수정"
	L["BugfixesTT"] = "기본 블리자드 프레임이 의도한 대로 작동하지 않는 경우를 위한 실험적인 버그 수정 시도입니다."
	L["BugfixHideVigor"] = "포스 하이드 활력"
	L["BugfixHideVigorTT"] = "분리되면 활력 바를 강제로 숨기고 동적 비행 탈것에 장착하면 다시 표시됩니다."
	L["FadeSpeedometer"] = "속도계 페이드"
	L["FadeSpeedometerTT"] = "글라이딩하지 않을 때 속도계 페이딩을 전환합니다."
	L["ShowVigorTooltip"] = "활력 도구 설명 표시"
	L["ShowVigorTooltipTT"] = "활력 막대에 표시되는 도구 설명을 전환합니다."
	L["FadeVigor"] = "활력이 희미해짐"
	L["FadeVigorTT"] = "활공하지 않을 때와 활력이 최대일 때 활력 바 페이드를 전환합니다."
	L["LightningRush"] = "정전기 충전 오브"
	L["LightningRushTT"] = "Algarian Stormrider Lightning Rush 능력에 사용되는 정전기 충전 오라용으로 제작된 사용자 정의 프레임을 전환합니다."
	L["DynamicFOV"] = "동적 시야"
	L["DynamicFOVTT"] = "글라이딩 속도에 따라 카메라 시야를 조정할 수 있습니다."
	L["Normal"] = "정상"
	L["Advanced"] = "고급의"
	L["Reverse"] = "뒤집다"
	L["Challenge"] = "도전"
	L["ReverseChallenge"] = "역방향 도전"
	L["Storm"] = "폭풍"
	L["COMMAND_help"] = "도움말"
	L["COMMAND_journal"] = "일지"
	L["COMMAND_listcommands"] = "명령어 목록:"
	L["COMMAND_dragonrider"] = "드래곤라이더"
	L["DragonRider"] = "드래곤 라이더"
	L["RightClick_TT_Line"] = "우클릭: 설정 열기"
	L["LeftClick_TT_Line"] = "좌클릭: 일지 열기"
	L["SlashCommands_TT_Line"] = "'/드래곤라이더' 추가 명령어"
	L["Score"] = "점수"
	L["Guide"] = "가이드"
	L["Settings"] = "설정"
	L["ComingSoon"] = "곧 출시 예정"
	L["UseAccountScores"] = "계정 점수 사용"
	L["UseAccountScoresTT"] = "이는 캐릭터의 점수 대신 상위 계정 레이스 점수를 표시합니다. 계정 점수는 별표 (*)로 표시됩니다."
	L["PersonalBest"] = "개인 최고: "
	L["AccountBest"] = "계정 최고: "
	L["BestCharacter"] = "최고 캐릭터: "
	L["GoldTime"] = "금 시간: "
	L["SilverTime"] = "은 시간: "


return end

if LOCALE == "zhCN" then
	-- Simplified Chinese translations go here
	-- Provided by 枫聖御雷 (https://legacy.curseforge.com/wow/addons/dragon-rider#c33)
	L["Vigor"] = "精力"
	L["Speedometer"] = "车速表"
	L["ToggleModelsName"] = "显示精力模型"
	L["ToggleModelsTT"] = "显示精力泡泡上的旋转模型效果。"
	L["SpeedPosPointName"] = "车速表位置"
	L["SpeedPosPointTT"] = "调整速度计相对于精力条的固定位置。"
	L["Top"] = "顶部"
	L["Bottom"] = "底部"
	L["Left"] = "左边"
	L["Right"] = "右边"
	L["SpeedPosXName"] = "车速表水平位置"
	L["SpeedPosXTT"] = "调整车速表的水平位置。"
	L["SpeedPosYName"] = "车速表垂直位置"
	L["SpeedPosYTT"] = "调整车速表的垂直位置。"
	L["SpeedScaleName"] = "车速表刻度"
	L["SpeedScaleTT"] = "调整车速表的刻度。"
	L["Large"] = "大的"
	L["Small"] = "小的"
	L["Units"] = "车速表文本"
	L["UnitsTT"] = "更改车速表上显示的单位。\n（机械上 1 米 = 1 码）"
	L["UnitsColor"] = "车速表文字颜色"
	L["UnitYards"] = "码/秒"
	L["Yards"] = "码数"
	L["UnitMiles"] = "英里/小时"
	L["Miles"] = "英里"
	L["UnitMeters"] = "米/秒"
	L["Meters"] = "米"
	L["UnitKilometers"] = "公里/小时"
	L["Kilometers"] = "公里"
	L["UnitPercent"] = "%"
	L["Percent"] = "百分比"
	L["SpeedTextScale"] = "车速表文字大小"
	L["SpeedTextScaleTT"] = "调整车速表上文字的大小。"
	L["Version"] = "版本 %s"
	L["ResetAllSettings"] = "重置所有龙骑士设置"
	L["ResetAllSettingsTT"] = "专门为此插件重置所有设置。 这将包括自定义颜色值。"
	L["ResetAllSettingsConfirm"] = "您确定要重置《龙骑士》的设置吗？"
	L["Low"] = "低"
	L["High"] = "高"
	L["ProgressBar"] = "车速表"
	L["ProgressBarColor"] = "车速表颜色"
	L["ColorPickerLowProgTT"] = "为车速表的低速值选择自定义颜色。 当玩家没有获得任何精力时就会发生这种情况。"
	L["ColorPickerMidProgTT"] = "为车速表的精力速度值标准时选择自定义颜色。 当玩家在标准速度范围内获得精力时，就会发生这种情况。"
	L["ColorPickerHighProgTT"] = "为车速表的高速值选择自定义颜色。 当玩家精力充沛但速度高于标准速度范围时，就会发生这种情况。"
	L["ColorPickerLowTextTT"] = "为速度值的低速度值选择自定义颜色。 当玩家没有获得任何精力时就会发生这种情况。"
	L["ColorPickerMidTextTT"] = "为速度值的精力速度值选择自定义颜色。 当玩家在标准速度范围内获得精力时，就会发生这种情况。"
	L["ColorPickerHighTextTT"] = "为速度值的高速值选择自定义颜色。 当玩家精力充沛但速度高于标准速度范围时，就会发生这种情况。"
	L["DragonridingTalents"] = "驭龙术天赋"
	L["OpenDragonridingTalents"] = "打开驭龙术天赋"
	L["OpenDragonridingTalentsTT"] = "打开驭龙术天赋窗口。"
	L["SideArtName"] = "侧面美化"
	L["SideArtTT"] = "切换主精力条两侧的美化。"
	L["BugfixesName"] = "Bug修复"
	L["BugfixesTT"] = "当默认暴雪框架未按预期工作时尝试进行实验性错误修复。"
	L["BugfixHideVigor"] = "强制隐藏精力条"
	L["BugfixHideVigorTT"] = "下坐骑时强制隐藏精力条，骑上驭龙术飞行坐骑时重新显示。"
	L["FadeSpeedometer"] = "淡出车速表"
	L["FadeSpeedometerTT"] = "在不滑行时切换速度计的淡出。"
	L["ShowVigorTooltip"] = "显示精力条上鼠标提示"
	L["ShowVigorTooltipTT"] = "切换精力条上鼠标提示的显示。"
	L["FadeVigor"] = "淡出精力条"
	L["FadeVigorTT"] = "在不滑翔和充满精力时切换精力条的淡出。"
	L["LightningRush"] = "静电荷球"
	L["LightningRushTT"] = "切换为阿加驭雷者“奔雷疾冲”技能使用的静电光环制作的自定义框架。"
	L["DynamicFOV"] = "动态视野"
	L["DynamicFOVTT"] = "能够根据飞行速度调整镜头视野。"
	L["Normal"] = "普通" -- translated (https://legacy.curseforge.com/wow/addons/dragon-rider#c43)
	L["Advanced"] = "进阶" -- translated
	L["Reverse"] = "反向" -- translated
	L["Challenge"] = "挑战" -- translated
	L["ReverseChallenge"] = "反向挑战" -- translated
	L["Storm"] = "风暴之速" -- translated
	L["COMMAND_help"] = "帮助"
	L["COMMAND_journal"] = "日志"
	L["COMMAND_listcommands"] = "命令列表:"
	L["COMMAND_dragonrider"] = "龙骑士"
	L["DragonRider"] = "龙骑手"
	L["RightClick_TT_Line"] = "右键点击：打开设置"
	L["LeftClick_TT_Line"] = "左键点击：打开日志"
	L["SlashCommands_TT_Line"] = "'/龙骑士' 以获取更多命令"
	L["Score"] = "得分"
	L["Guide"] = "指南"
	L["Settings"] = "设置"
	L["ComingSoon"] = "即将推出"
	L["UseAccountScores"] = "使用账号分数" -- translated
	L["UseAccountScoresTT"] = "这将显示您账号中最高的得分，而不是您当前角色的得分。账号得分用星号 (*) 表示。" -- translated
	L["PersonalBest"] = "个人最佳: "
	L["AccountBest"] = "账号最佳: " -- translated
	L["BestCharacter"] = "最佳角色: "
	L["GoldTime"] = "金牌时间: "
	L["SilverTime"] = "银牌时间: "
	--non-official translations

return end

if LOCALE == "zhTW" then
	-- Traditional Chinese translations go here
	L["Vigor"] = "活力"
	L["Speedometer"] = "車速表"
	L["ToggleModelsName"] = "展現活力模特"
	L["ToggleModelsTT"] = "顯示活力氣泡上的旋轉模型效果。"
	L["SpeedPosPointName"] = "車速表位置"
	L["SpeedPosPointTT"] = "調整速度計相對於活力條的固定位置。"
	L["Top"] = "頂部"
	L["Bottom"] = "底部"
	L["Left"] = "左邊"
	L["Right"] = "正確的"
	L["SpeedPosXName"] = "車速表水平位置"
	L["SpeedPosXTT"] = "調整車速表的水平位置。"
	L["SpeedPosYName"] = "車速表垂直位置"
	L["SpeedPosYTT"] = "調整車速表的垂直位置。"
	L["SpeedScaleName"] = "車速表刻度"
	L["SpeedScaleTT"] = "調整車速表的刻度。"
	L["Large"] = "大的"
	L["Small"] = "小的"
	L["Units"] = "車速表文本"
	L["UnitsTT"] = "更改車速表上顯示的單位。\n（機械上 1 米 = 1 碼）"
	L["UnitsColor"] = "車速表文字顏色"
	L["UnitYards"] = "碼/秒"
	L["Yards"] = "碼數"
	L["UnitMiles"] = "英里/小時"
	L["Miles"] = "英里"
	L["UnitMeters"] = "米/秒"
	L["Meters"] = "米"
	L["UnitKilometers"] = "公里/小時"
	L["Kilometers"] = "公里"
	L["UnitPercent"] = "%"
	L["Percent"] = "百分比"
	L["SpeedTextScale"] = "車速表文字大小"
	L["SpeedTextScaleTT"] = "調整車速表上文字的大小。"
	L["Version"] = "版本 %s"
	L["ResetAllSettings"] = "重置所有龍騎士設置"
	L["ResetAllSettingsTT"] = "專門為此插件重置所有設置。 這將包括自定義顏色值。"
	L["ResetAllSettingsConfirm"] = "您確定要重置《龍騎士》的設置嗎？"
	L["Low"] = "低的"
	L["High"] = "高的"
	L["ProgressBar"] = "車速表"
	L["ProgressBarColor"] = "車速表顏色"
	L["ColorPickerLowProgTT"] = "為速度計的低速值選擇自定義顏色。 當玩家沒有獲得任何活力時就會發生這種情況。"
	L["ColorPickerMidProgTT"] = "為速度計的活力速度值選擇自定義顏色。 當玩家在標準速度範圍內獲得活力時，就會發生這種情況。"
	L["ColorPickerHighProgTT"] = "為車速表的高速值選擇自定義顏色。 當玩家精力充沛但速度高於標準速度範圍時，就會發生這種情況。"
	L["ColorPickerLowTextTT"] = "為速度值的低速度值選擇自定義顏色。 當玩家沒有獲得任何活力時就會發生這種情況。"
	L["ColorPickerMidTextTT"] = "為速度值的活力速度值選擇自定義顏色。 當玩家在標準速度範圍內獲得活力時，就會發生這種情況。"
	L["ColorPickerHighTextTT"] = "為速度值的高速值選擇自定義顏色。 當玩家精力充沛但速度高於標準速度範圍時，就會發生這種情況。"
	L["DragonridingTalents"] = "龍騎天賦"
	L["OpenDragonridingTalents"] = "開放龍騎天賦"
	L["OpenDragonridingTalentsTT"] = "打開龍騎天賦窗口。"
	L["SideArtName"] = "側面藝術"
	L["SideArtTT"] = "切換主活力條兩側的藝術。"
	L["BugfixesName"] = "Bug修復"
	L["BugfixesTT"] = "當預設暴雪框架未如預期工作時嘗試進行實驗性錯誤修復。"
	L["BugfixHideVigor"] = "強制隱藏活力"
	L["BugfixHideVigorTT"] = "拆卸時強制隱藏活力條，安裝在動態飛行坐騎上時重新顯示。"
	L["FadeSpeedometer"] = "褪色車速表"
	L["FadeSpeedometerTT"] = "不滑行時切換速度計的淡出。"
	L["ShowVigorTooltip"] = "顯示活力工具提示"
	L["ShowVigorTooltipTT"] = "切換活力條上顯示的工具提示。"
	L["FadeVigor"] = "褪色活力"
	L["FadeVigorTT"] = "在不滑翔和充滿活力時切換活力條的淡出。"
	L["LightningRush"] = "靜電荷球"
	L["LightningRushTT"] = "切換為阿爾加里亞風暴騎士閃電衝鋒能力所使用的靜電光環製作的自訂框架。"
	L["DynamicFOV"] = "動態視野"
	L["DynamicFOVTT"] = "能夠根據滑翔速度調整相機視野。"
	L["Normal"] = "普通的"
	L["Advanced"] = "先進的"
	L["Reverse"] = "反向"
	L["Challenge"] = "挑戰"
	L["ReverseChallenge"] = "反向挑戰"
	L["Storm"] = "風暴"
	L["COMMAND_help"] = "幫助"
	L["COMMAND_journal"] = "日誌"
	L["COMMAND_listcommands"] = "指令列表:"
	L["COMMAND_dragonrider"] = "龍騎士"
	L["DragonRider"] = "龍騎手"
	L["RightClick_TT_Line"] = "右鍵點擊：打開設置"
	L["LeftClick_TT_Line"] = "左鍵點擊：打開日誌"
	L["SlashCommands_TT_Line"] = "'/龍騎士' 以獲取其他指令"
	L["Score"] = "得分"
	L["Guide"] = "指南"
	L["Settings"] = "設置"
	L["ComingSoon"] = "即將推出"
	L["UseAccountScores"] = "使用帳戶分數"
	L["UseAccountScoresTT"] = "這將顯示您帳戶中的最高種族分數，而不是您角色的分數。帳戶分數以星號 (*) 表示。"
	L["PersonalBest"] = "個人最佳: "
	L["AccountBest"] = "帳戶最佳: "
	L["BestCharacter"] = "最佳角色: "
	L["GoldTime"] = "金牌時間: "
	L["SilverTime"] = "銀牌時間: "

return end
